"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var components_1 = require("../components");
var Emitter_1 = require("../common/Emitter");
var util_1 = require("../util");
require("../util/global");
require("../assets/style.less");
var View = /** @class */ (function () {
    function View(el, option) {
        var _this = this;
        this.eventHandlers = [];
        this.onDateClick = function () { };
        this.onDateChange = function () { };
        this.onActivityClick = function () { };
        this.onActivityOver = function () { };
        this.onActivityOut = function () { };
        this.onNext = function () { };
        this.onPrev = function () { };
        //observer data
        this._data = {};
        var date = option.date, activities = option.activities, selected = option.selected;
        Object.keys(option).forEach(function (key) { return option[key] && (_this[key] = option[key]); });
        this.$el = el;
        this.now = new Date();
        var dates = this.parseDate(date);
        //set data
        this.data = __assign({}, dates, { selected: selected,
            activities: activities });
        this.container = new components_1.Container({
            attrs: {
                tagName: 'div',
                class: 'f-fullcalendar'
            }
        }, this.data);
        this.render();
    }
    View.prototype.parseDate = function (date) {
        return {
            year: date.getFullYear(),
            month: date.getMonth() + 1,
            day: date.getDate()
        };
    };
    Object.defineProperty(View.prototype, "data", {
        get: function () {
            return this._data;
        },
        set: function (value) {
            this._data = value;
            this.container && this.container.setData(value);
            this.onDateChange(value);
            this.trigger('onDateChange', value);
        },
        enumerable: true,
        configurable: true
    });
    View.prototype.render = function () {
        this.container.mount(this.$el);
        this.bindHandlers();
    };
    View.prototype._onActivityLineOverHandler = function (_event, target) {
        var hoverColor = target.getAttribute('hover-background');
        var id = target.getAttribute('data-id');
        var lines = document.querySelectorAll(".f-activities__line[data-id=\"" + id + "\"]");
        for (var i = 0; i < lines.length; i++) {
            lines[i].style.background = hoverColor;
        }
        this.trigger('onActivityOver', _event, target);
    };
    View.prototype._onActivityLineOutHandler = function (_event, target) {
        var background = target.getAttribute('background');
        var id = target.getAttribute('data-id');
        var lines = document.querySelectorAll(".f-activities__line[data-id=\"" + id + "\"]");
        for (var i = 0; i < lines.length; i++) {
            lines[i].style.background = background;
        }
        this.trigger('onActivityOut', _event, target);
    };
    View.prototype._onDateClickHandler = function (event, target) {
        var date = target.getAttribute('date');
        if (!date)
            return;
        this.data = __assign({}, this.data, { selected: new Date(date) });
        this.onDateClick(event, date, target);
        this.trigger('onDateClick', event, date, target);
    };
    View.prototype._onActivityClickHandler = function (event, target) {
        event.stopImmediatePropagation();
        var index = target.getAttribute('data-id');
        var activities = this.data.activities;
        this.onActivityClick(event, activities[index], target);
        this.trigger('onActivityClick', event, activities[index], target);
    };
    View.prototype.bindHandlers = function () {
        this.eventHandlers = [
            util_1.addEventListenerBySelcetor(this.$el, 'click', '.f-toolbar-next', this.nextMonth.bind(this)),
            util_1.addEventListenerBySelcetor(this.$el, 'click', '.f-toolbar-prev', this.prevMonth.bind(this)),
            util_1.addEventListenerBySelcetor(this.$el, 'click', '.f-toolbar-backtoday', this.goToday.bind(this)),
            util_1.addEventListenerBySelcetor(this.$el, 'click', '.f-activities__line', this._onActivityClickHandler.bind(this)),
            util_1.addEventListenerBySelcetor(this.$el, 'click', '.f-day__item', this._onDateClickHandler.bind(this)),
            util_1.addEventListenerBySelcetor(this.$el, 'mouseover', '.f-activities__line', this._onActivityLineOverHandler.bind(this)),
            util_1.addEventListenerBySelcetor(this.$el, 'mouseout', '.f-activities__line', this._onActivityLineOutHandler.bind(this))
        ];
    };
    View.prototype.unBindHandlers = function () {
        this.eventHandlers.forEach(function (handler) { return handler(); });
    };
    View.prototype.destroy = function () {
        this.unBindHandlers();
        this.container.destroy();
    };
    return View;
}());
exports.default = View;
Emitter_1.default.mixToClass(View);
//# sourceMappingURL=view.js.map